@@ -87,8 +87,12 @@ extern "C" {
 #  define MRN_HANDLER_HAVE_GET_PARENT_FOREIGN_KEY_LIST
 #endif
 
-#if (MYSQL_VERSION_ID < 50600)
-#  define MRN_HANDLER_HAVE_GET_TABLESPACE_NAME 1
+#if MYSQL_VERSION_ID < 50600
+#  define MRN_HANDLER_HAVE_GET_TABLESPACE_NAME
+#endif
+
+#if MYSQL_VERSION_ID >= 50607
+#  define MRN_HANDLER_HAVE_SET_HA_SHARE_REF
 #endif
 
 #if MYSQL_VERSION_ID >= 50500
@@ -117,7 +121,7 @@ extern "C" {
 #  define MRN_HAVE_HA_EXTRA_PREPARE_FOR_FORCED_CLOSE
 #endif
 
-#if MYSQL_VERSION_ID >= 50607 && !defined(MRN_MARIADB_P)
+#if MYSQL_VERSION_ID >= 50607
 #  define MRN_HAVE_HA_EXTRA_EXPORT
 #endif
 
@@ -153,7 +157,6 @@ extern "C" {
 
 #if MYSQL_VERSION_ID >= 50500
 #  define MRN_ROW_BASED_CHECK_IS_METHOD
-#  define MRN_OPTION_BITS_IS_UNDER_VARIABLES
 #endif
 
 #if MYSQL_VERSION_ID >= 50600
@@ -236,6 +239,8 @@ private:
   KEY         *wrap_altered_table_key_info;
   TABLE_SHARE *wrap_altered_table_share;
   KEY         *wrap_altered_table_share_key_info;
+#else
+  KEY         *wrap_alter_key_info;
 #endif
   int mrn_lock_type;
 
@@ -269,6 +274,7 @@ private:
   grn_obj *key_accessor;
   grn_obj *sorted_result;
   grn_obj *matched_record_keys;
+  String  *blob_buffers;
 
   // for error report
   uint dup_key;
@@ -584,6 +590,9 @@ private:
                                   const char *value, uint value_length);
   void storage_store_field_integer(Field *field,
                                    const char *value, uint value_length);
+  void storage_store_field_unsigned_integer(Field *field,
+                                            const char *value,
+                                            uint value_length);
   void storage_store_field_float(Field *field,
                                  const char *value, uint value_length);
   void storage_store_field_timestamp(Field *field,
