@@ -31,7 +31,7 @@
 #  define mysql_mutex_unlock(mutex) pthread_mutex_unlock(mutex)
 #endif
 
-#if MYSQL_VERSION_ID >= 50604 && !defined(MRN_MARIADB_P)
+#if MYSQL_VERSION_ID >= 50604
 #  define MRN_HAVE_MYSQL_TYPE_TIMESTAMP2
 #  define MRN_HAVE_MYSQL_TYPE_DATETIME2
 #  define MRN_HAVE_MYSQL_TYPE_TIME2
@@ -85,11 +85,14 @@
 
 #if MYSQL_VERSION_ID >= 50607
 #  define MRN_GET_ERROR_MESSAGE current_thd->get_stmt_da()->message()
+#  define MRN_GET_CURRENT_ROW_FOR_WARNING(thd) thd->get_stmt_da()->current_row_for_warning()
 #else
 #  if MYSQL_VERSION_ID >= 50500
 #    define MRN_GET_ERROR_MESSAGE current_thd->stmt_da->message()
+#    define MRN_GET_CURRENT_ROW_FOR_WARNING(thd) thd->warning_info->current_row_for_warning()
 #  else
 #    define MRN_GET_ERROR_MESSAGE current_thd->main_da.message()
+#    define MRN_GET_CURRENT_ROW_FOR_WARNING(thd) thd->row_count
 #  endif
 #endif
 
@@ -114,4 +117,12 @@
 #  define MRN_HAVE_GET_TABLE_DEF_KEY
 #endif
 
+#if defined(MRN_MARIADB_P) && MYSQL_VERSION_ID >= 100004
+#  define MRN_TABLE_SHARE_HAVE_LOCK_SHARE
+#endif
+
+#if MYSQL_VERSION_ID >= 50404
+#  define MRN_TABLE_SHARE_HAVE_LOCK_HA_DATA
+#endif
+
 #endif /* MRN_MYSQL_COMPAT_H_ */
