@@ -50,6 +50,13 @@
 extern HASH *mrn_table_def_cache;
 #endif
 
+#ifdef MRN_TABLE_SHARE_HAVE_LOCK_SHARE
+extern PSI_mutex_key *mrn_table_share_lock_share;
+#endif
+#ifdef MRN_TABLE_SHARE_HAVE_LOCK_HA_DATA
+extern PSI_mutex_key *mrn_table_share_lock_ha_data;
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -864,6 +871,24 @@ MRN_SHARE *mrn_get_share(const char *table_name, TABLE *table, int *error)
       wrap_table_share->primary_key = share->wrap_primary_key;
       wrap_table_share->keys_in_use.init(share->wrap_keys);
       wrap_table_share->keys_for_keyread.init(share->wrap_keys);
+#ifdef MRN_TABLE_SHARE_HAVE_LOCK_SHARE
+#  ifdef WIN32
+      mysql_mutex_init(*mrn_table_share_lock_share,
+                       &(wrap_table_share->LOCK_share), MY_MUTEX_INIT_SLOW);
+#  else
+      mysql_mutex_init(key_TABLE_SHARE_LOCK_share,
+                       &(wrap_table_share->LOCK_share), MY_MUTEX_INIT_SLOW);
+#  endif
+#endif
+#ifdef MRN_TABLE_SHARE_HAVE_LOCK_HA_DATA
+#  ifdef WIN32
+      mysql_mutex_init(*mrn_table_share_lock_ha_data,
+                       &(wrap_table_share->LOCK_ha_data), MY_MUTEX_INIT_FAST);
+#  else
+      mysql_mutex_init(key_TABLE_SHARE_LOCK_ha_data,
+                       &(wrap_table_share->LOCK_ha_data), MY_MUTEX_INIT_FAST);
+#  endif
+#endif
       share->wrap_table_share = wrap_table_share;
     }
 
@@ -910,6 +935,14 @@ int mrn_free_share(MRN_SHARE *share)
     mrn_free_share_alloc(share);
     thr_lock_delete(&share->lock);
     pthread_mutex_destroy(&share->mutex);
+    if (share->wrapper_mode) {
+#ifdef MRN_TABLE_SHARE_HAVE_LOCK_SHARE
+      mysql_mutex_destroy(&(share->wrap_table_share->LOCK_share));
+#endif
+#ifdef MRN_TABLE_SHARE_HAVE_LOCK_HA_DATA
+      mysql_mutex_destroy(&(share->wrap_table_share->LOCK_ha_data));
+#endif
+    }
     my_free(share, MYF(0));
   }
   DBUG_RETURN(0);
